<?php
/*
Plugin Name: TNG Sitemap Plugin
Plugin URI: http://jontang.se/tng-sitemap-plugin
Description: A plugin for display a html sitemap with a shortcode.
Version: 1.0
Author: Jon Täng
Author URI: http://jontang.se
License: GPL2
*/

load_plugin_textdomain('tng_sitemap', false, basename( dirname( __FILE__ ) ) . '/languages' );
// register Foo_Widget widget
//add_action( 'widgets_init', create_function( '', 'register_widget( "tng_embed_widget" );' ) );

/**
 * Get site authors
 */
function tng_get_authors(){
	$args = array(
	    //'orderby'       => 'name', 
	    //'order'         => 'ASC', 
	    //'number'        => null,
	    //'optioncount'   => false, 
	    //'exclude_admin' => true, 
	    //'show_fullname' => false,
	    //'hide_empty'    => true,
	    'echo'          => false,
	    //'feed'          => '', 
	    //'feed_image'    => '',
	    //'feed_type'     => '',
	    //'style'         => 'list',
	    //'html'          => true 
	);
	$output = sprintf( '<h3>%s</h3>', __( 'Authors', 'tng_sitemap' ) );
	
	$output .= '<ul id="sitmap-authors">';
	$output .= wp_list_authors( $args );
	$output .= '</ul> <!-- end #sitemap-authors -->';
	
	return $output;
}
/**
 * Get blog post sorted by categories
 * 
 * @return string $output
 */
function tng_get_sitemap_blog() {
	global $post;
	$cats = get_terms( 'category' );
		
	$output = '<ul id="sitemap-blog">';
	
	foreach ( $cats as $cat ) :
		//echo '<pre>'; print_r( $cat ); echo '</pre>';
		$output .= '<li class="category"><h5><a href="'. get_term_link( $cat, $cat->taxonomy ) .'">'. $cat->name .'</a></h5>';
		
		$output .= '<ul class="category '.$cat->slug.'">';
		
		$post_args = array(
			'posts_per_page'   => -1,
			'orderby'          => 'post_date',
			'order'            => 'DESC',
			'post_type'        => 'post',
			'post_status'      => 'publish',
			'suppress_filters' => true,
			'tax_query' => array(
				array(
					'taxonomy' => $cat->taxonomy,
					'field' => 'id',
					'terms' => $cat->term_id
				)
			) 
		);
		
		$posts = get_posts( $post_args );
		
		foreach ( $posts as $post ) : setup_postdata( $post ); 
		
			$output .= '<li class="post"><a href="'. get_permalink() .'">'. get_the_title() .'</a></li>';
		
		endforeach; wp_reset_query();
	
		$output .= '</ul> <!-- end .category -->';
		$output .= '</li>';
	
	endforeach;
	
	$output .= '</ul> <!-- end #sitemap-blog -->';
	
	return $output;
}

/**
 * Get menu children
 * 
 * @param int $item_id
 * @return string $output
 */
function tng_get_menu_children( $item_id ) {
	global $post;
	$menu_args = array(
		'posts_per_page' => -1,
		'post_type' => 'nav_menu_item',
		'orderby'          => 'menu_order',
		'order'            => 'ASC',
		'meta_query' => array(
			array(
				'key' => '_menu_item_menu_item_parent',
				'value' => $item_id
			)
		)
	);
	$menu_items = get_posts( $menu_args );
	
	if ( !$menu_items )
		return false;
			
	$output = '<ul class="page-children">';
	
	foreach ( $menu_items as $menu_item ) :
		$children = tng_get_menu_children( $menu_item->ID ); 
		$meta = get_post_meta( $menu_item->ID, '_menu_item_object_id', true);
		$post = get_page($meta); setup_postdata( $post ); 
	
		$output .= '<li class="page"><h5><a href="'. get_permalink() .'">'. get_the_title() .'</a><h5>';
				
		if ( $children )
			$output .= $children;
		
		$output .= '</li>';
		
	endforeach; wp_reset_query();
	
	$output .= '</ul> <!-- end .page-children -->';
	
	return $output;
}
/**
 * Get menu parents
 * 
 * @param int $item_id
 * @return string $output
 */
function tng_get_menu_parents( $menu_id ) {
	$blog = get_option( 'page_for_posts' );
	$frontpage = get_option( 'page_on_front' );
	
	//echo '<pre>'; print_r( $fontpage ); echo '</pre>';
	
	$menu_args = array(
		'posts_per_page'   => -1,
		'orderby'          => 'menu_order',
		'order'            => 'ASC',
		'post_type'        => 'nav_menu_item',
		'post_status'      => 'publish',
		'tax_query' => array(
			array(
				'taxonomy' => nav_menu,
				'field' => 'id',
				'terms' => $menu_id
			)
		),
		'meta_query' => array(
			array(
				'key' => '_menu_item_menu_item_parent',
				'value' => 0
			)
		)
	);

	global $post;
	$menu_items = get_posts( $menu_args );
	
	$output = sprintf( '<h3>%s</h3>', __( 'Content', 'tng_sitemap' ) );
	
	$output .= '<ul id="sitemap">';
	foreach ( $menu_items as $menu_item ) : 
		$meta = get_post_meta( $menu_item->ID, '_menu_item_object_id', true);
		$children = tng_get_menu_children( $menu_item->ID );
		
		$post = get_page($meta); setup_postdata( $post );

		if ( $frontpage == $post->ID )
			$output .= '<li class="page"><h4><a href="'. get_permalink() .'">'. sprintf( '%s (%s)', get_the_title(), __('Home', 'tng_sitemap') ) .'</a></h4>';
		else
			$output .= '<li class="page"><h4><a href="'. get_permalink() .'">'. get_the_title() .'</a></h4>';
		
		if ( $children )
			$output .= $children;
		
		if ( $blog == $post->ID )
			$output .= tng_get_sitemap_blog();
		
		$output .= '</li>';
		
	endforeach; wp_reset_query();
	
	$output .= '</ul> <!-- end #sitemap -->';
	
	return $output;
}

/**
 * Outputs sitemap
 * 
 * @param array $atts
 * @return echos html
 */
function tng_output_sitemap( $atts ) {
	extract( shortcode_atts( array(
		'menu_id' => 2,
		'show_author' => true,
	), $atts ) );
	
	$output = '';
	
	// Authors
	if ($show_author)
		$output .= tng_get_authors();
	
	// Menu structure
	$output .= tng_get_menu_parents( $menu_id ); 
	
	// Output
	echo $output;
}
add_shortcode( 'tng_sitemap', 'tng_output_sitemap' );